==> 1.0.2.tar.gz: doc/GeoApi.md <==
# forestvpn_api.api.GeoApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getCountries**](GeoApi.md#getCountries) | **GET** /countries/ | List of available countries
[**getLocations**](GeoApi.md#getLocations) | **GET** /locations/ | List of available locations


# **getCountries**
> List<Country> getCountries()

List of available countries

### Example 
```dart
import 'package:forestvpn_api/api.dart';

var api_instance = new GeoApi();

try { 
    var result = api_instance.getCountries();
    print(result);
} catch (e) {
    print("Exception when calling GeoApi->getCountries: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<Country>**](Country.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getLocations**
> List<Location> getLocations()

List of available locations

### Example 
```dart
import 'package:forestvpn_api/api.dart';

var api_instance = new GeoApi();

try { 
    var result = api_instance.getLocations();
    print(result);
} catch (e) {
    print("Exception when calling GeoApi->getLocations: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<Location>**](Location.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> 1.1.1.tar.gz: doc/GeoApi.md <==
# forestvpn_api.api.GeoApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getCountries**](GeoApi.md#getCountries) | **GET** /countries/ | List of available countries
[**getLocations**](GeoApi.md#getLocations) | **GET** /locations/ | List of available locations


# **getCountries**
> List<Country> getCountries()

List of available countries

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = GeoApi();

try { 
    var result = api_instance.getCountries();
    print(result);
} catch (e) {
    print("Exception when calling GeoApi->getCountries: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<Country>**](Country.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getLocations**
> List<Location> getLocations()

List of available locations

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = GeoApi();

try { 
    var result = api_instance.getLocations();
    print(result);
} catch (e) {
    print("Exception when calling GeoApi->getLocations: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<Location>**](Location.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
